## ----setup, include = FALSE----------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE, message = FALSE,warning = FALSE,
  comment = "#>"
)

## ------------------------------------------------------------------------
library(giscourse)
conn<-connect()
landcover("Arne, Dorset") ->arne_lcover
sssi("Arne, Dorset") ->arne_sssi
phabitat("Arne, Dorset") -> arne_phabitat
osm("Arne, Dorset")->arne_osm

## ------------------------------------------------------------------------
mapviewOptions(legend=FALSE)
mapview(arne_lcover,zcol="bhab",burst=TRUE,  hide = TRUE) %>% extras()

## ------------------------------------------------------------------------
library(tmap)
arne_lcover %>% filter(bhab !="Saltwater") %>% 

qtm("bhab") + tmap_style("classic") + tmap_options(legend.outside=TRUE) + tm_scale_bar() + tm_compass(type="arrow")

## ------------------------------------------------------------------------
lon<--1.5
lat<-50.86
landcover(lon,lat,dist=2000) ->nf_lcover
sssi(lon,lat,dist=2000) ->nf_sssi
phabitat(lon,lat,dist=2000) -> nf_phabitat
osm(lon,lat,dist=2000)->nf_osm


## ------------------------------------------------------------------------
mapview(nf_lcover,zcol="bhab",burst=TRUE,  hide = TRUE) %>% extras()

## ------------------------------------------------------------------------

nf_lcover %>% 

qtm("bhab") + tmap_style("classic") + tmap_options(legend.outside=TRUE) + tm_scale_bar() + tm_compass(type="arrow")

## ------------------------------------------------------------------------

nf_lcover %>% group_by(bhab) %>% summarise(area_ha=round(sum(area)/10000,1)) -> areas

## ------------------------------------------------------------------------
library(ggplot2)

areas %>% arrange(area_ha) %>%  mutate(bhab = factor(bhab, bhab)) %>%
ggplot(aes(x=bhab,y=area_ha,lab=area_ha)) +geom_bar(stat="identity",fill="grey") + geom_label(aes(x = bhab, y = area_ha, label = paste(area_ha,"ha"))) + coord_flip() + theme_bw()

## ----eval=FALSE----------------------------------------------------------
#  st_write(arne_lcover, dsn="geodata.gpkg", layer="arne_lcover")
#  st_write(arne_sssi, dsn="geodata.gpkg", layer="arne_sssi")
#  ## Etc ..

